==> flutter_windows_1.21.0-9.2.pre-beta.zip: flutter/.pub-cache/hosted/pub.dartlang.org/xml-4.3.0/lib/src/xml/nodes/document_fragment.dart <==
library xml.nodes.document_fragment;

import 'package:petitparser/petitparser.dart';

import '../entities/default_mapping.dart';
import '../entities/entity_mapping.dart';
import '../mixins/has_children.dart';
import '../parser.dart';
import '../utils/cache.dart';
import '../utils/exceptions.dart';
import '../utils/node_type.dart';
import '../visitors/visitor.dart';
import 'node.dart';

/// XML document fragment node.
class XmlDocumentFragment extends XmlNode with XmlHasChildren {
  /// Return an [XmlDocumentFragment] for the given [input] string, or throws an
  /// [XmlParserException] if the input is invalid.
  ///
  /// Note: It is the responsibility of the caller to provide a standard Dart
  /// [String] using the default UTF-16 encoding.
  factory XmlDocumentFragment.parse(String input,
      {XmlEntityMapping entityMapping = const XmlDefaultEntityMapping.xml()}) {
    final result = documentFragmentParserCache[entityMapping].parse(input);
    if (result.isFailure) {
      final lineAndColumn =
          Token.lineAndColumnOf(result.buffer, result.position);
      throw XmlParserException(result.message,
          buffer: result.buffer,
          position: result.position,
          line: lineAndColumn[0],
          column: lineAndColumn[1]);
    }
    return result.value;
  }

  /// Create a document fragment node with `children`.
  XmlDocumentFragment([Iterable<XmlNode> childrenIterable = const []]) {
    children.initialize(this, childrenNodeTypes);
    children.addAll(childrenIterable);
  }

  @override
  XmlNodeType get nodeType => XmlNodeType.DOCUMENT_FRAGMENT;

  @override
  dynamic accept(XmlVisitor visitor) => visitor.visitDocumentFragment(this);
}

/// Supported child node types.
const Set<XmlNodeType> childrenNodeTypes = {
  XmlNodeType.CDATA,
  XmlNodeType.COMMENT,
  XmlNodeType.DECLARATION,
  XmlNodeType.DOCUMENT_TYPE,
  XmlNodeType.ELEMENT,
  XmlNodeType.PROCESSING,
  XmlNodeType.TEXT,
};

/// Internal cache of parsers for a specific entity mapping.
final XmlCache<XmlEntityMapping, Parser> documentFragmentParserCache =
    XmlCache((entityMapping) {
  final definition = XmlParserDefinition(entityMapping);
  return definition.build(start: definition.documentFragment).end();
}, 5);

==> flutter_windows_2.13.0-0.4.pre-beta.zip: flutter/.pub-cache/hosted/pub.dartlang.org/xml-5.4.1/lib/src/xml/nodes/document_fragment.dart <==
import 'package:petitparser/petitparser.dart';

import '../entities/default_mapping.dart';
import '../entities/entity_mapping.dart';
import '../mixins/has_children.dart';
import '../parser.dart';
import '../utils/cache.dart';
import '../utils/exceptions.dart';
import '../utils/node_type.dart';
import '../visitors/visitor.dart';
import 'node.dart';

/// XML document fragment node.
class XmlDocumentFragment extends XmlNode with XmlHasChildren<XmlNode> {
  /// Return an [XmlDocumentFragment] for the given [input] string, or throws an
  /// [XmlParserException] if the input is invalid.
  ///
  /// Note: It is the responsibility of the caller to provide a standard Dart
  /// [String] using the default UTF-16 encoding.
  factory XmlDocumentFragment.parse(String input,
      {XmlEntityMapping? entityMapping}) {
    final mapping = entityMapping ?? defaultEntityMapping;
    final parser = documentFragmentParserCache[mapping];
    final result = parser.parse(input);
    if (result.isFailure) {
      final lineAndColumn =
          Token.lineAndColumnOf(result.buffer, result.position);
      throw XmlParserException(result.message,
          buffer: result.buffer,
          position: result.position,
          line: lineAndColumn[0],
          column: lineAndColumn[1]);
    }
    return result.value;
  }

  /// Create a document fragment node with `children`.
  XmlDocumentFragment([Iterable<XmlNode> childrenIterable = const []]) {
    children.initialize(this, childrenNodeTypes);
    children.addAll(childrenIterable);
  }

  @override
  XmlNodeType get nodeType => XmlNodeType.DOCUMENT_FRAGMENT;

  @override
  XmlDocumentFragment copy() =>
      XmlDocumentFragment(children.map((each) => each.copy()));

  @override
  dynamic accept(XmlVisitor visitor) => visitor.visitDocumentFragment(this);
}

/// Supported child node types.
const Set<XmlNodeType> childrenNodeTypes = {
  XmlNodeType.CDATA,
  XmlNodeType.COMMENT,
  XmlNodeType.DECLARATION,
  XmlNodeType.DOCUMENT_TYPE,
  XmlNodeType.ELEMENT,
  XmlNodeType.PROCESSING,
  XmlNodeType.TEXT,
};

/// Internal cache of parsers for a specific entity mapping.
final XmlCache<XmlEntityMapping, Parser> documentFragmentParserCache =
    XmlCache((entityMapping) {
  // ignore: deprecated_member_use_from_same_package
  final definition = XmlParserDefinition(entityMapping);
  return definition.build(start: definition.documentFragment).end();
}, 5);
